@@ -207,7 +207,6 @@ void decomposearc(pathptr thepath)
       (*newspline)->ctrl[3].y = E2.y;
 
       calcspline(*newspline);
-      thepath->parts++;
    }
 
    /* Delete the arc */
@@ -2249,6 +2248,9 @@ void UDrawArc(arcptr thearc, float passwidth)
 
    UfTransformbyCTM(DCTM, thearc->points, tmppoints, thearc->number);
    strokepath(tmppoints, thearc->number, thearc->style, scaledwidth);
+   if (thearc->cycle != NULL) {
+      UDrawXLine(thearc->position, thearc->position);
+   }
 }
 
 /*-------------------------------------------------------------------------*/
@@ -2367,6 +2369,7 @@ void UDrawObject(objinstptr theinstance, short level, int passcolor,
        if ((*areagen)->type & DRAW_HIDE) continue;
 
        if (defaultcolor != DOFORALL) {
+
 	  if ((*areagen)->color != curcolor) {
 	     if ((*areagen)->color == DEFAULTCOLOR)
 		curcolor = defaultcolor;
